summaryrefslogtreecommitdiff
path: root/src/geom/align.rs
diff options
context:
space:
mode:
authorLaurenz <laurmaedje@gmail.com>2021-01-03 00:12:09 +0100
committerLaurenz <laurmaedje@gmail.com>2021-01-03 00:12:09 +0100
commitaae67bd572ad86f4c57e364daa51a9dc883b8913 (patch)
tree0aba021e0748ebad2197ea390385ec5f93ccbc6e /src/geom/align.rs
parent1c40dc42e7bc7b799b77f06d25414aca59a044ba (diff)
Move and rename many things 🚛
Diffstat (limited to 'src/geom/align.rs')
-rw-r--r--src/geom/align.rs4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/geom/align.rs b/src/geom/align.rs
index 7c4d965f..8f02a4ea 100644
--- a/src/geom/align.rs
+++ b/src/geom/align.rs
@@ -1,7 +1,7 @@
use super::*;
-/// The alignment of a box in a container.
-pub type BoxAlign = Gen<Align>;
+/// The alignment of a child in a container.
+pub type ChildAlign = Gen<Align>;
/// Where to align something along a directed axis.
#[derive(Debug, Copy, Clone, Eq, PartialEq, Ord, PartialOrd)]